@@ -81,10 +81,10 @@ pcheck.varchar <- function(var2check, varnm=NULL, checklst, gui=FALSE, caption=N
 		paste(varnm, "is invalid"))
   }
 
-  if (is.null(var2check) || is.na(var2check) || length(var2check) == 0 || gsub(" ", "", var2check) == "") {
+  if (is.null(var2check) || any(is.na(var2check)) || length(var2check) == 0 || any(gsub(" ", "", var2check) == "")) {
     if (gui) {
       var2check <- select.list(checklst, title=caption, multiple=multiple, ...)
-      if (length(var2check) == 0 || var2check == "") {
+      if (length(var2check) == 0 || any(var2check == "")) {
         stop("NULL")
       }
     } else {
@@ -110,7 +110,7 @@ pcheck.varchar <- function(var2check, varnm=NULL, checklst, gui=FALSE, caption=N
     } else if (gui) {
       message(warn)
       var2check <- select.list(checklst, title=caption, multiple=multiple, ...)
-      if (length(var2check) == 0 || var2check == "") stop("")
+      if (length(var2check) == 0 || any(var2check == "")) stop("")
     } else {
       if (stopifinvalid) {
         if (multiple) {
@@ -141,7 +141,7 @@ pcheck.dsn <- function(dsn, dbconnopen=TRUE) {
       dsn <- paste(dsn, ext, sep=".")
   }
   tabext <- getext(dsn)
-  if (is.na(tabext) || tabext == "NA") {
+  if (any(is.na(tabext)) || any(tabext == "NA")) {
     stop("dsn must include extension")
   }
   if (tabext %in% c("sqlite", "gpkg")) {
@@ -300,7 +300,7 @@ pcheck.table <- function(tab=NULL, tab_dsn=NULL, tabnm=NULL, tabqry=NULL,
   }
 
   tabext <- getext(tab_dsn)
-  if (is.na(tabext) || tabext == "NA") {
+  if (any(is.na(tabext)) || any(tabext == "NA")) {
     if (dir.exists(tab_dsn) && file.exists(paste(tab_dsn, tab, sep="/"))) {
       tab_dsn <- paste(tab_dsn, tab, sep="/")
       tabext <- getext(tab_dsn)
@@ -327,7 +327,7 @@ pcheck.table <- function(tab=NULL, tab_dsn=NULL, tabnm=NULL, tabqry=NULL,
           stop(tab, " not in ", tab_dsn)
         }
       }
-      if (!is.null(tabqry) && !is.na(tabqry)) {
+      if (!is.null(tabqry) && any(!is.na(tabqry))) {
         tabx <- data.table(DBI::dbGetQuery(dbconn, tabqry))
       } else {
         tabx <- data.table(DBI::dbReadTable(dbconn, tab))
@@ -355,7 +355,7 @@ pcheck.table <- function(tab=NULL, tab_dsn=NULL, tabnm=NULL, tabqry=NULL,
       tabx <- tabx[apply(tabx, 1, function(x) sum(is.na(x) | x=="NA" | x=="")) != ncol(x),]
   }
 
-  if (returnsf && "sf" %in% class(tabx)) {
+  if (returnsf && is(tabx, "sf")) {
     return(tabx)
   } else {
     if (returnDT) {
@@ -535,12 +535,12 @@ pcheck.object <- function(obj=NULL, objnm=NULL, warn=NULL, caption=NULL,
       if (exists(obj, envir=.GlobalEnv) && is.list(get(obj))) {
         #message(tab, " exists in Global Environment")
         return(get(obj))
-      } else if (!is.na(getext(obj)) && file.exists(obj)) {
+      } else if (any(!is.na(getext(obj))) && file.exists(obj)) {
         objx <- get(load(obj))
         if (!is.list(objx)) stop("must be list object")
-      } else if (!is.na(getext(obj)) && !file.exists(obj)) {
+      } else if (any(!is.na(getext(obj))) && !file.exists(obj)) {
         stop("file does not exist")
-      } else if (is.na(getext(obj))) {
+      } else if (any(is.na(getext(obj)))) {
         stop(objnm, " must be a list object or filename")
       } else {
         stop(objnm, " must be a list object or filename")
@@ -649,7 +649,7 @@ pcheck.output <- function(out_fmt="csv", out_dsn=NULL, outfolder=NULL,
 		outfn.date=outfn.date, overwrite=overwrite_dsn, outfn.default="data",
 		ext=ext, add=add_layer, append=append_layer)
 
-    if (out_fmt %in% c("sqlite", "gpkg") && createSQLite) {
+    if (any(out_fmt %in% c("sqlite", "gpkg")) && createSQLite) {
       gpkg <- ifelse(out_fmt == "gpkg", TRUE, FALSE)
       out_dsn <- DBcreateSQLite(out_dsn, gpkg=gpkg)
     }
@@ -683,7 +683,7 @@ pcheck.colors <- function(colorlst, n) {
    if (!is.vector(colorlst) || !is.character(colorlst)) {
      stop("colorlst must be a character vector of color names, hexadecimal codes, or brewer palettes")
    }
-   if (length(colorlst) == 1 && colorlst %in% brewerlst) {
+   if (length(colorlst) == 1 && any(colorlst %in% brewerlst)) {
      if (n < 3) {
        stop("minimum number for brewer palettes is 3")
      }
@@ -717,9 +717,9 @@ pcheck.areaunits <- function(unitarea, areavar, areaunits, metric=FALSE) {
   areausedvar <- checknm("AREAUSED", names(unitarea))
   unitarea[[areausedvar]] <- unitarea[[areavar]]
   if (areaunits != outunits) {
-    if (areaunits == "acres" && outunits == "hectares") {
+    if (any(areaunits == "acres") && any(outunits == "hectares")) {
       unitarea[[areausedvar]] <- unitarea[[areausedvar]] * 0.4046860
-    } else if (areaunits == "hectares" && outunits == "acres") {
+    } else if (any(areaunits == "hectares") && any(outunits == "acres")) {
       unitarea[[areausedvar]] <- unitarea[[areausedvar]] / 0.4046860
     } else {
       stop("invalid units... cannot convert ", areaunits, " to ", outunits)
@@ -805,8 +805,8 @@ pcheck.spatial <- function(layer=NULL, dsn=NULL, sql=NA, fmt=NULL, tabnm=NULL,
 
   if (!is.null(dsn)) {
     ext.dsn <- getext(dsn)
-    if (!file.exists(dsn) && (is.na(ext.dsn) || ext.dsn == "NA")) {
-      if (!is.null(fmt) && fmt %in% fmtlst)
+    if (!file.exists(dsn) && (any(is.na(ext.dsn)) || any(ext.dsn == "NA"))) {
+      if (!is.null(fmt) && any(fmt %in% fmtlst))
         dsn <- paste(dsn, fmt, sep=".")
       if (!file.exists(dsn)) dsn <- NULL
     }
@@ -825,7 +825,7 @@ pcheck.spatial <- function(layer=NULL, dsn=NULL, sql=NA, fmt=NULL, tabnm=NULL,
     }
   } else {
     ext.layer <- getext(layer)
-    if (!is.na(ext.layer) && ext.layer != "NA" && file.exists(layer)) {
+    if (any(!is.na(ext.layer)) && any(ext.layer != "NA") && file.exists(layer)) {
       if (ext.layer %in% c("shp", "csv")) {
         dsn <- layer
         layer <- basename.NoExt(dsn)
